const loadSecrets = async ({
  databaseName,
  escapeId,
  escape,
  secretsTableName,
  executeStatement
}, filter) => {
  const {
    idx,
    limit,
    skip
  } = filter;
  const databaseNameAsId = escapeId(databaseName);
  const secretsTableNameAsId = escapeId(secretsTableName);
  const searchIdx = idx == null ? 0 : idx;
  const skipRows = skip === undefined ? 0 : skip;
  const sql = `
    SELECT idx, id, secret FROM ${databaseNameAsId}.${secretsTableNameAsId}
    WHERE secret IS NOT NULL AND idx >= ${+searchIdx}
    ORDER BY "idx" ASC
    LIMIT ${+limit} OFFSET ${skipRows}`;
  const rows = await executeStatement(sql);
  const secrets = [];

  for (const secret of rows) {
    secrets.push({
      secret: secret.secret,
      id: secret.id,
      idx: +secret.idx
    });
  }

  return {
    secrets: secrets,
    idx: secrets.length ? secrets[secrets.length - 1].idx + 1 : null
  };
};

export default loadSecrets;
//# sourceMappingURL=load-secrets.js.map